@@ -18,9 +18,6 @@
 
 // KDE
 #include <kauthorized.h>
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-#include <kdelibs4migration.h>
-#endif
 #include <klocalizedstring.h>
 #include <ksharedconfig.h>
 
@@ -46,32 +43,8 @@ inline bool nameBasedOrdering(const ActivityInfo &info, const ActivityInfo &othe
 }
 }
 
-Activities::Private::KDE4ConfigurationTransitionChecker::KDE4ConfigurationTransitionChecker()
-{
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    // Checking whether we need to transfer the KActivities/KDE4
-    // configuration file to the new location.
-    const QString newConfigLocation = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QLatin1Char('/') + ACTIVITY_MANAGER_CONFIG_FILE_NAME;
-
-    if (QFile(newConfigLocation).exists()) {
-        return;
-    }
-    // Testing for kdehome
-    Kdelibs4Migration migration;
-    if (!migration.kdeHomeFound()) {
-        return;
-    }
-
-    QString oldConfigFile(migration.locateLocal("config", QStringLiteral("activitymanagerrc")));
-    if (!oldConfigFile.isEmpty()) {
-        QFile(oldConfigFile).copy(newConfigLocation);
-    }
-#endif
-}
-
 Activities::Private::Private(Activities *parent)
-    : kde4ConfigurationTransitionChecker()
-    , config(QStringLiteral("kactivitymanagerdrc"))
+    : config(QStringLiteral("kactivitymanagerdrc"))
     , q(parent)
 {
     // qCDebug(KAMD_ACTIVITIES) << "Using this configuration file:"
@@ -123,17 +96,17 @@ Activities::Private::Private(Activities *parent)
         // are no running activities, and enlists all of them as stopped.
         // In that case, we will pretend all of them are running
         qCWarning(KAMD_LOG_ACTIVITIES) << "The config file enlisted all activities as stopped";
-        for (const auto &keys : activities.keys()) {
-            activities[keys] = Activities::Running;
+        for (auto activityKey = activities.keyBegin(); activityKey != activities.keyEnd(); ++activityKey) {
+            activities[*activityKey] = Activities::Running;
         }
     }
 }
 
 void Activities::Private::updateSortedActivityList()
 {
-    QVector<ActivityInfo> a;
-    for (const auto &activity : activities.keys()) {
-        a.append(q->ActivityInformation(activity));
+    QList<ActivityInfo> a;
+    for (auto activityKey = activities.keyBegin(); activityKey != activities.keyEnd(); ++activityKey) {
+        a.append(q->ActivityInformation(*activityKey));
     }
 
     std::sort(a.begin(), a.end(), &nameBasedOrdering);
@@ -171,7 +144,7 @@ bool Activities::Private::setCurrentActivity(const QString &activity)
         // If the activity is empty, this means we are entering a limbo state
         if (activity.isEmpty()) {
             currentActivity.clear();
-            emit q->CurrentActivityChanged(currentActivity);
+            Q_EMIT q->CurrentActivityChanged(currentActivity);
             return true;
         }
 
@@ -192,7 +165,7 @@ bool Activities::Private::setCurrentActivity(const QString &activity)
 
     scheduleConfigSync();
 
-    emit q->CurrentActivityChanged(activity);
+    Q_EMIT q->CurrentActivityChanged(activity);
 
     return true;
 }
@@ -255,7 +228,7 @@ QString Activities::Private::addActivity(const QString &name)
 
     updateSortedActivityList();
 
-    emit q->ActivityAdded(activity);
+    Q_EMIT q->ActivityAdded(activity);
 
     scheduleConfigSync();
 
@@ -316,7 +289,7 @@ void Activities::Private::removeActivity(const QString &activity)
         ensureCurrentActivityIsRunning();
     }
 
-    emit q->ActivityRemoved(activity);
+    Q_EMIT q->ActivityRemoved(activity);
 
     QMetaObject::invokeMethod(q, "ActivityRemoved", Qt::QueuedConnection, Q_ARG(QString, activity));
 
@@ -370,18 +343,18 @@ void Activities::Private::setActivityState(const QString &activity, Activities::
 
     switch (state) {
     case Activities::Running:
-        emit q->ActivityStarted(activity);
+        Q_EMIT q->ActivityStarted(activity);
         break;
 
     case Activities::Stopped:
-        emit q->ActivityStopped(activity);
+        Q_EMIT q->ActivityStopped(activity);
         break;
 
     default:
         break;
     }
 
-    emit q->ActivityStateChanged(activity, state);
+    Q_EMIT q->ActivityStateChanged(activity, state);
 
     if (configNeedsUpdating) {
         QReadLocker lock(&activitiesLock);
@@ -572,8 +545,8 @@ ActivityInfo Activities::ActivityInformation(const QString &activity) const
         d->activity##What##Config().writeEntry(activity, value);                                                                                               \
         d->scheduleConfigSync();                                                                                                                               \
                                                                                                                                                                \
-        emit Activity##What##Changed(activity, value);                                                                                                         \
-        emit ActivityChanged(activity);                                                                                                                        \
+        Q_EMIT Activity##What##Changed(activity, value);                                                                                                         \
+        Q_EMIT ActivityChanged(activity);                                                                                                                        \
     }
 
 CREATE_GETTER_AND_SETTER(Name)
@@ -618,3 +591,7 @@ int Activities::ActivityState(const QString &activity) const
     QReadLocker lock(&d->activitiesLock);
     return d->activities.contains(activity) ? d->activities[activity] : Invalid;
 }
+
+#include "moc_Activities.cpp"
+
+#include "moc_Activities_p.cpp"
